<?php

/**
 * @package     Sprinix_Offer
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\Offer\Block\Frontend\TemplateData;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use Sprinix\Offer\Model\ResourceModel\Post\CollectionFactory;
use Magento\Cms\Model\Template\FilterProvider;
use Sprinix\Offer\Helper\Data;
use Psr\Log\LoggerInterface;

/**
 * Class Popup
 * @package Sprinix\Offer\Block\Frontend\TemplateData
 */
class Popup extends Template
{
    /**
     * @var CollectionFactory
     */
    public $collection;

    /**
     * @var FilterProvider
     */
    public $filterProvider;

    /**
     * @var Data
     */
    public $helper;

    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * Popup constructor.
     * @param Context $context
     * @param CollectionFactory $collectionFactory
     * @param FilterProvider $filterProvider
     * @param Data $helper
     * @param LoggerInterface $logger
     * @param array $data
     */
    public function __construct(
        Context $context,
        CollectionFactory $collectionFactory,
        FilterProvider $filterProvider,
        Data $helper,
        LoggerInterface $logger,
        array $data = []
    )
    {
        $this->collection = $collectionFactory;
        $this->filterProvider = $filterProvider;
        $this->helper = $helper;
        $this->logger = $logger;
        parent::__construct($context, $data);
    }

    /**
     * @return mixed
     */
    public function moduleEnable()
    {
        return $this->helper->enableModule();
    }

    /**
     * @return string
     */
    public function getCollection()
    {
        $popup = "";
        try {
         $collections = $this->collection->create();
         $collections->addFieldToFilter('is_active',"1");
         $dataCollections = $collections->getData();
         $currentTime = $this->helper->currentTime();
         $CurrentStore = $this->helper->currentStore();
         $currentgroupId = $this->helper->customerGroupId();
         if($dataCollections) {
            $fromDateTime = [];
            foreach ($dataCollections as $collection) {
                $FromTime = $collection['from_date'];
                $toTime = $collection['to_date'];
                $storeSelect = $collection['storeviews'];
                $groupId = $collection['customer_group'];
                if ($currentTime >= $FromTime && $currentTime <= $toTime) {
                    if (@str_contains($storeSelect, $CurrentStore)) {
                        if (str_contains($groupId,$currentgroupId)) {
                            $fromDateTime[] = $FromTime;
                            $minFromDate = min($fromDateTime);
                            if ($FromTime == $minFromDate ) {
                                $popup = $collection['template'];
                                $popup = $this->filterProvider->getPageFilter()->filter($popup);
                            }
                        }
                    }
                }
            }
            return $popup;
         }
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
        return $popup;
    }
}
