<?php

/**
 * @package     Sprinix_Offer
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\Offer\Controller\Adminhtml\Index;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Sprinix\Offer\Model\PostFactory;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\Result;
use Magento\Framework\Controller\ResultInterface;

/**
 * Class Delete
 * @package Sprinix\Offer\Controller\Adminhtml\Index
 */
class Delete extends Action
{
    /**
     * @var PostFactory
     */
    public $postFactory;

    /**
     * Delete constructor.
     * @param Context $context
     * @param PostFactory $postFactory
     */
    public function __construct(
        Context $context,
        PostFactory $postFactory
    )
    {
        $this->postFactory = $postFactory;
        parent::__construct($context);
    }

    /**
     * @return ResponseInterface|Result\Redirect|ResultInterface
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();
        $id = $this->getRequest()->getParam('id');
        try {
            $postModel = $this->postFactory->create();
            $postModel->load($id);
            $postModel->delete();
            $this->messageManager->addSuccessMessage(__('Offer deleted.'));
        } catch (\Exception $e) {
            $this->messageManager->addErrorMessage($e->getMessage());
        }
        return $resultRedirect->setPath('*/*/');
    }

    /**
     * @return bool
     */
    public function _isAllowed()
    {
        return $this->_authorization->isAllowed('Sprinix_Offer::delete');
    }
}
