<?php

/**
 * @package     Sprinix_Offer
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\Offer\Controller\Adminhtml\Index;
use Magento\Backend\App\Action\Context;
use Sprinix\Offer\Model\PostFactory;
use Magento\Backend\App\Action;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\ResultInterface;

/**
 * Class Save
 * @package Sprinix\Offer\Controller\Adminhtml\Index
 */
class Save extends Action
{
    /**
     * @var PostFactory
     */
    protected $postFactory;

    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;

    /**
     * Save constructor.
     * @param StoreManagerInterface $storeManager
     * @param Context $context
     * @param PostFactory $postFactory
     */
    public function __construct(
        StoreManagerInterface $storeManager,
       Context $context,
       PostFactory $postFactory
    )
    {
        parent::__construct($context);
        $this->postFactory = $postFactory;
        $this->storeManager = $storeManager;
    }

    /**
     * @return ResponseInterface|ResultInterface|void
     */
    public function execute()
    {
        $data = $this->getRequest()->getPostValue();
        if (!$data) {
            $this->_redirect('offer/index/add');
            return;
        }
        try {
            $model = $this->postFactory->create();
            $offerTemplate=$data['template'];
            if ($offerTemplate) {
                $data['template'] = $offerTemplate;
                $model->setData($data);
            }
            $customerGroup = $data['customer_group'];
            $store = $data['storeviews'];
            $storeName=[];
            foreach($store as $storeId){
                $storeName[] = $this->storeManager->getStore($storeId)->getName();
            }
            $data['store_name'] = implode(",",$storeName);
            $data['storeviews'] = implode(",",$store);
            $data['customer_group'] = implode(",",$customerGroup);

            $model->setData($data);
            if (isset($data['id'])) {
                $model->setEntityId($data['id']);
            }
            $model->save();
            $this->messageManager->addSuccess(__('Offer Popup successfully saved.'));
        }
        catch (\Exception $e) {
            $this->messageManager->addError(__($e->getMessage()));
        }
        $this->_redirect('*/*/index');
    }
}
