<?php

/**
 * @package     Sprinix_Offer
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */

namespace Sprinix\Offer\Helper;
use Magento\Store\Model\ScopeInterface;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Framework\Stdlib\DateTime\TimezoneInterface;
use Magento\Customer\Model\Session;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\Exception\LocalizedException;

/**
 * Class Data
 * @package Sprinix\Offer\Helper
 */
class Data extends AbstractHelper
{
    /**
     * enable extension
     */
    const IS_ENABLED = 'offerpopup/general/enable';

    /**
     * default store value
     */
    const  DEFAULT_STORE = 0;

    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    /**
     * @var TimezoneInterface
     */
    private $dateTime;

    /**
     * @var Session
     */
    private $customerSession;

    /**
     * Data constructor.
     * @param Context $context
     * @param StoreManagerInterface $storeManager
     * @param TimezoneInterface $dateTime
     */
    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager,
        TimezoneInterface $dateTime,
        Session $customerSession
    )
    {
        $this->storeManager = $storeManager;
        $this->dateTime = $dateTime;
        $this->customerSession = $customerSession;
        parent::__construct($context);
    }

    /**
     * @return mixed
     */
    public function enableModule()
    {
        return $this->scopeConfig->getValue(self::IS_ENABLED,
            ScopeInterface::SCOPE_STORE );
    }

    /**
     * @return int
     */
    public  function currentStore()
    {
        try {
            return  $this->storeManager->getStore()->getId();
        } catch(NoSuchEntityException $e) {
          return self::DEFAULT_STORE;
        }
    }

    /**
     * @return string
     */
    public  function currentTime()
    {
        return $this->dateTime->date()->format('Y-m-d H:i:s');
    }

    /**
     * @return int
     * @throws LocalizedException
     * @throws NoSuchEntityException
     */
    public function customerGroupId()
    {
        return $this->customerSession->getCustomerGroupId();
    }
}
